==> eam-wshub-proxyclient-11.6-2-sources.jar: net/datastream/schemas/mp_fields/CONTRACTCLAUSEID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour CONTRACTCLAUSEID_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="CONTRACTCLAUSEID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CLASSID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}SEQUENCENUMBER"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "CONTRACTCLAUSEID_Type", propOrder = {
    "classid",
    "sequencenumber"
})
public class CONTRACTCLAUSEID_Type {

    @XmlElement(name = "CLASSID", required = true)
    protected CLASSID_Type classid;
    @XmlElement(name = "SEQUENCENUMBER")
    protected long sequencenumber;

    /**
     * Obtient la valeur de la propriété classid.
     * 
     * @return
     *     possible object is
     *     {@link CLASSID_Type }
     *     
     */
    public CLASSID_Type getCLASSID() {
        return classid;
    }

    /**
     * Définit la valeur de la propriété classid.
     * 
     * @param value
     *     allowed object is
     *     {@link CLASSID_Type }
     *     
     */
    public void setCLASSID(CLASSID_Type value) {
        this.classid = value;
    }

    /**
     * Obtient la valeur de la propriété sequencenumber.
     * 
     */
    public long getSEQUENCENUMBER() {
        return sequencenumber;
    }

    /**
     * Définit la valeur de la propriété sequencenumber.
     * 
     */
    public void setSEQUENCENUMBER(long value) {
        this.sequencenumber = value;
    }

}

==> eam-wshub-proxyclient-12.1-0-sources.jar: net/datastream/schemas/mp_fields/CONTRACTCLAUSEID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for CONTRACTCLAUSEID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="CONTRACTCLAUSEID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CLASSID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}SEQUENCENUMBER"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "CONTRACTCLAUSEID_Type", propOrder = {
    "classid",
    "sequencenumber"
})
public class CONTRACTCLAUSEID_Type {

    @XmlElement(name = "CLASSID", required = true)
    protected CLASSID_Type classid;
    @XmlElement(name = "SEQUENCENUMBER")
    protected long sequencenumber;

    /**
     * Gets the value of the classid property.
     * 
     * @return
     *     possible object is
     *     {@link CLASSID_Type }
     *     
     */
    public CLASSID_Type getCLASSID() {
        return classid;
    }

    /**
     * Sets the value of the classid property.
     * 
     * @param value
     *     allowed object is
     *     {@link CLASSID_Type }
     *     
     */
    public void setCLASSID(CLASSID_Type value) {
        this.classid = value;
    }

    /**
     * Gets the value of the sequencenumber property.
     * 
     */
    public long getSEQUENCENUMBER() {
        return sequencenumber;
    }

    /**
     * Sets the value of the sequencenumber property.
     * 
     */
    public void setSEQUENCENUMBER(long value) {
        this.sequencenumber = value;
    }

}
